@@ -1,5 +1,5 @@
 /* GTK - The GIMP Toolkit
- * Copyright (C) 2000 Red Hat, Inc. 
+ * Copyright (C) 2000 Red Hat, Inc.
  * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
  *
  * This library is free software; you can redistribute it and/or
@@ -22,33 +22,44 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
+
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_COLOR_SELECTION_H__
 #define __GTK_COLOR_SELECTION_H__
 
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkvbox.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 #define GTK_TYPE_COLOR_SELECTION			(gtk_color_selection_get_type ())
-#define GTK_COLOR_SELECTION(obj)			(GTK_CHECK_CAST ((obj), GTK_TYPE_COLOR_SELECTION, GtkColorSelection))
-#define GTK_COLOR_SELECTION_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_COLOR_SELECTION, GtkColorSelectionClass))
-#define GTK_IS_COLOR_SELECTION(obj)			(GTK_CHECK_TYPE ((obj), GTK_TYPE_COLOR_SELECTION))
-#define GTK_IS_COLOR_SELECTION_CLASS(klass)		(GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_COLOR_SELECTION))
-#define GTK_COLOR_SELECTION_GET_CLASS(obj)              (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_COLOR_SELECTION, GtkColorSelectionClass))
+#define GTK_COLOR_SELECTION(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_COLOR_SELECTION, GtkColorSelection))
+#define GTK_COLOR_SELECTION_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_COLOR_SELECTION, GtkColorSelectionClass))
+#define GTK_IS_COLOR_SELECTION(obj)			(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_COLOR_SELECTION))
+#define GTK_IS_COLOR_SELECTION_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_COLOR_SELECTION))
+#define GTK_COLOR_SELECTION_GET_CLASS(obj)              (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_COLOR_SELECTION, GtkColorSelectionClass))
 
 
 typedef struct _GtkColorSelection       GtkColorSelection;
+typedef struct _GtkColorSelectionPrivate  GtkColorSelectionPrivate;
 typedef struct _GtkColorSelectionClass  GtkColorSelectionClass;
 
-
 typedef void (* GtkColorSelectionChangePaletteFunc) (const GdkColor    *colors,
                                                      gint               n_colors);
+
+/**
+ * GtkColorSelectionChangePaletteWithScreenFunc:
+ * @screen:
+ * @colors:
+ * @n_colors:
+ *
+ * Since: 2.2
+ */
 typedef void (* GtkColorSelectionChangePaletteWithScreenFunc) (GdkScreen         *screen,
 							       const GdkColor    *colors,
 							       gint               n_colors);
@@ -58,7 +69,7 @@ struct _GtkColorSelection
   GtkVBox parent_instance;
 
   /* < private_data > */
-  gpointer private_data;
+  GtkColorSelectionPrivate *private_data;
 };
 
 struct _GtkColorSelectionClass
@@ -77,7 +88,7 @@ struct _GtkColorSelectionClass
 
 /* ColorSelection */
 
-GtkType    gtk_color_selection_get_type                (void) G_GNUC_CONST;
+GType      gtk_color_selection_get_type                (void) G_GNUC_CONST;
 GtkWidget *gtk_color_selection_new                     (void);
 gboolean   gtk_color_selection_get_has_opacity_control (GtkColorSelection *colorsel);
 void       gtk_color_selection_set_has_opacity_control (GtkColorSelection *colorsel,
@@ -88,20 +99,29 @@ void       gtk_color_selection_set_has_palette         (GtkColorSelection *color
 
 
 void     gtk_color_selection_set_current_color   (GtkColorSelection *colorsel,
-						  GdkColor          *color);
+						  const GdkColor    *color);
 void     gtk_color_selection_set_current_alpha   (GtkColorSelection *colorsel,
 						  guint16            alpha);
 void     gtk_color_selection_get_current_color   (GtkColorSelection *colorsel,
 						  GdkColor          *color);
 guint16  gtk_color_selection_get_current_alpha   (GtkColorSelection *colorsel);
 void     gtk_color_selection_set_previous_color  (GtkColorSelection *colorsel,
-						  GdkColor          *color);
+						  const GdkColor    *color);
 void     gtk_color_selection_set_previous_alpha  (GtkColorSelection *colorsel,
 						  guint16            alpha);
 void     gtk_color_selection_get_previous_color  (GtkColorSelection *colorsel,
 						  GdkColor          *color);
 guint16  gtk_color_selection_get_previous_alpha  (GtkColorSelection *colorsel);
 
+void     gtk_color_selection_set_current_rgba    (GtkColorSelection *colorsel,
+                                                  const GdkRGBA     *rgba);
+void     gtk_color_selection_get_current_rgba    (GtkColorSelection *colorsel,
+                                                  GdkRGBA           *rgba);
+void     gtk_color_selection_set_previous_rgba   (GtkColorSelection *colorsel,
+                                                  const GdkRGBA     *rgba);
+void     gtk_color_selection_get_previous_rgba   (GtkColorSelection *colorsel,
+                                                  GdkRGBA           *rgba);
+
 gboolean gtk_color_selection_is_adjusting        (GtkColorSelection *colorsel);
 
 gboolean gtk_color_selection_palette_from_string (const gchar       *str,
@@ -110,25 +130,8 @@ gboolean gtk_color_selection_palette_from_string (const gchar       *str,
 gchar*   gtk_color_selection_palette_to_string   (const GdkColor    *colors,
                                                   gint               n_colors);
 
-#ifndef GDK_MULTIHEAD_SAFE
-GtkColorSelectionChangePaletteFunc           gtk_color_selection_set_change_palette_hook             (GtkColorSelectionChangePaletteFunc           func);
-#endif
-
 GtkColorSelectionChangePaletteWithScreenFunc gtk_color_selection_set_change_palette_with_screen_hook (GtkColorSelectionChangePaletteWithScreenFunc func);
 
-#ifndef GTK_DISABLE_DEPRECATED
-/* Deprecated calls: */
-void gtk_color_selection_set_color         (GtkColorSelection *colorsel,
-					    gdouble           *color);
-void gtk_color_selection_get_color         (GtkColorSelection *colorsel,
-					    gdouble           *color);
-void gtk_color_selection_set_update_policy (GtkColorSelection *colorsel,
-					    GtkUpdateType      policy);
-#endif /* GTK_DISABLE_DEPRECATED */
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif /* __GTK_COLOR_SELECTION_H__ */
