@@ -22,11 +22,11 @@
 
 #include "config.h"
 
-#include "gtktoolpaletteprivate.h"
-
-#include <gtk/gtk.h>
 #include <math.h>
 #include <string.h>
+
+#include "gtktoolpaletteprivate.h"
+#include "gtktypebuiltins.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
 
@@ -84,7 +84,6 @@ struct _GtkToolItemGroupPrivate
   gboolean           animation;
   gint64             animation_start;
   GSource           *animation_timeout;
-  GtkExpanderStyle   expander_style;
   gint               expander_size;
   gint               header_spacing;
   PangoEllipsizeMode ellipsize;
@@ -266,43 +265,52 @@ gtk_tool_item_group_header_draw_cb (GtkWidget *widget,
 {
   GtkToolItemGroup *group = GTK_TOOL_ITEM_GROUP (data);
   GtkToolItemGroupPrivate* priv = group->priv;
-  GtkExpanderStyle expander_style;
   GtkOrientation orientation;
   gint x, y, width, height;
   GtkTextDirection direction;
+  GtkStyleContext *context;
+  GtkStateFlags state = 0;
 
   orientation = gtk_tool_shell_get_orientation (GTK_TOOL_SHELL (group));
-  expander_style = priv->expander_style;
   direction = gtk_widget_get_direction (widget);
   width = gtk_widget_get_allocated_width (widget);
   height = gtk_widget_get_allocated_height (widget);
+  context = gtk_widget_get_style_context (widget);
+
+  if (!priv->collapsed)
+    state |= GTK_STATE_FLAG_ACTIVE;
+
+  gtk_style_context_save (context);
+  gtk_style_context_set_state (context, state);
+  gtk_style_context_add_class (context, GTK_STYLE_CLASS_EXPANDER);
 
   if (GTK_ORIENTATION_VERTICAL == orientation)
     {
-      if (GTK_TEXT_DIR_RTL == direction)
-        x = width - priv->expander_size / 2;
-      else
-        x = priv->expander_size / 2;
+      gtk_style_context_add_class (context, GTK_STYLE_CLASS_VERTICAL);
 
-      y = height / 2;
+      if (GTK_TEXT_DIR_RTL == direction)
+        x = width;
+      else
+        x = 0;
+
+      y = height / 2 - priv->expander_size / 2;
     }
   else
     {
-      x = width / 2;
-      y = priv->expander_size / 2;
-
-      /* Unfortunatly gtk_paint_expander() doesn't support rotated drawing
-       * modes. Luckily the following shady arithmetics produce the desired
-       * result. */
-      expander_style = GTK_EXPANDER_EXPANDED - expander_style;
+      gtk_style_context_add_class (context, GTK_STYLE_CLASS_HORIZONTAL);
+      x = width / 2 - priv->expander_size / 2;
+      y = 0;
     }
 
-  gtk_paint_expander (gtk_widget_get_style (widget),
-                      cr,
-                      gtk_widget_get_state (priv->header),
-                      GTK_WIDGET (group),
-                      "tool-palette-header", x, y,
-                      expander_style);
+  /* The expander is the only animatable region */
+  gtk_style_context_push_animatable_region (context, GUINT_TO_POINTER (1));
+
+  gtk_render_expander (context, cr, x, y,
+                       priv->expander_size,
+                       priv->expander_size);
+
+  gtk_style_context_pop_animatable_region (context);
+  gtk_style_context_restore (context);
 
   return FALSE;
 }
@@ -382,7 +390,6 @@ gtk_tool_item_group_init (GtkToolItemGroup *group)
   priv->children = NULL;
   priv->header_spacing = DEFAULT_HEADER_SPACING;
   priv->expander_size = DEFAULT_EXPANDER_SIZE;
-  priv->expander_style = GTK_EXPANDER_EXPANDED;
 
   priv->label_widget = gtk_label_new (NULL);
   gtk_misc_set_alignment (GTK_MISC (priv->label_widget), 0.0, 0.5);
@@ -635,14 +642,12 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
   GtkAllocation item_area;
 
   GtkOrientation orientation;
-  GtkToolbarStyle style;
 
   gint min_rows;
   guint border_width;
 
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
   orientation = gtk_tool_shell_get_orientation (GTK_TOOL_SHELL (group));
-  style = gtk_tool_shell_get_style (GTK_TOOL_SHELL (group));
 
   /* figure out the size of homogeneous items */
   gtk_tool_item_group_get_item_size (group, &item_size, TRUE, &min_rows);
@@ -658,7 +663,9 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
   item_area.width = 0;
   item_area.height = 0;
 
-  /* figure out the required columns (n_columns) and rows (n_rows) to place all items */
+  /* figure out the required columns (n_columns) and rows (n_rows)
+   * to place all items
+   */
   if (!priv->collapsed || !priv->animation || priv->animation_timeout)
     {
       guint n_columns;
@@ -733,7 +740,9 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
 
           row_min_width = g_new0 (guint, n_rows);
 
-          /* calculate minimal and maximal required cols and minimal required rows */
+          /* calculate minimal and maximal required cols and minimal
+           * required rows
+           */
           for (it = priv->children; it != NULL; it = it->next)
             {
               GtkToolItemGroupChild *child = it->data;
@@ -784,7 +793,9 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
               min_col = MAX (min_col, row_min_width[i]);
             }
 
-          /* simple linear search for minimal required columns for the given maximal number of rows (n_rows) */
+          /* simple linear search for minimal required columns
+           * for the given maximal number of rows (n_rows)
+           */
           for (n_columns = min_col; n_columns < max_col; n_columns ++)
             {
               new_row = TRUE;
@@ -878,20 +889,19 @@ gtk_tool_item_group_real_size_allocate (GtkWidget     *widget,
   GtkAllocation item_area;
 
   GtkOrientation orientation;
-  GtkToolbarStyle style;
 
   GList *it;
 
   gint n_columns, n_rows = 1;
   gint min_rows;
   guint border_width;
+  GtkTextDirection direction;
 
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
-  GtkTextDirection direction = gtk_widget_get_direction (widget);
+  direction = gtk_widget_get_direction (widget);
 
   orientation = gtk_tool_shell_get_orientation (GTK_TOOL_SHELL (group));
-  style = gtk_tool_shell_get_style (GTK_TOOL_SHELL (group));
 
   /* chain up */
   GTK_WIDGET_CLASS (gtk_tool_item_group_parent_class)->size_allocate (widget, allocation);
@@ -1111,13 +1121,13 @@ gtk_tool_item_group_set_focus_cb (GtkWidget *window,
           if (gtk_widget_translate_coordinates
                 (widget, p, 0, 0, NULL, &y) && y < 0)
             {
-              y += adjustment->value;
+              y += gtk_adjustment_get_value (adjustment);
               gtk_adjustment_clamp_page (adjustment, y, y + allocation.height);
             }
           else if (gtk_widget_translate_coordinates (widget, p, 0, allocation.height, NULL, &y) &&
                    y > p_allocation.height)
             {
-              y += adjustment->value;
+              y += gtk_adjustment_get_value (adjustment);
               gtk_adjustment_clamp_page (adjustment, y - allocation.height, y);
             }
         }
@@ -1135,13 +1145,13 @@ gtk_tool_item_group_set_focus_cb (GtkWidget *window,
           if (gtk_widget_translate_coordinates
                 (widget, p, 0, 0, &x, NULL) && x < 0)
             {
-              x += adjustment->value;
+              x += gtk_adjustment_get_value (adjustment);
               gtk_adjustment_clamp_page (adjustment, x, x + allocation.width);
             }
           else if (gtk_widget_translate_coordinates (widget, p, allocation.width, 0, &x, NULL) &&
                    x > p_allocation.width)
             {
-              x += adjustment->value;
+              x += gtk_adjustment_get_value (adjustment);
               gtk_adjustment_clamp_page (adjustment, x - allocation.width, x);
             }
 
@@ -1199,10 +1209,12 @@ gtk_tool_item_group_realize (GtkWidget *widget)
   GdkDisplay *display;
   gint attributes_mask;
   guint border_width;
+  GtkStyleContext *context;
 
   gtk_widget_set_realized (widget, TRUE);
 
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
+  context = gtk_widget_get_style_context (widget);
 
   gtk_widget_get_allocation (widget, &allocation);
 
@@ -1230,9 +1242,7 @@ gtk_tool_item_group_realize (GtkWidget *widget)
 
   gdk_window_set_user_data (window, widget);
 
-  gtk_widget_style_attach (widget);
-  gtk_style_set_background (gtk_widget_get_style (widget),
-                            window, GTK_STATE_NORMAL);
+  gtk_style_context_set_background (context, window);
 
   gtk_container_forall (GTK_CONTAINER (widget),
                         (GtkCallback) gtk_widget_set_parent_window,
@@ -1253,11 +1263,10 @@ gtk_tool_item_group_unrealize (GtkWidget *widget)
 }
 
 static void
-gtk_tool_item_group_style_set (GtkWidget *widget,
-                               GtkStyle  *previous_style)
+gtk_tool_item_group_style_updated (GtkWidget *widget)
 {
   gtk_tool_item_group_header_adjust_style (GTK_TOOL_ITEM_GROUP (widget));
-  GTK_WIDGET_CLASS (gtk_tool_item_group_parent_class)->style_set (widget, previous_style);
+  GTK_WIDGET_CLASS (gtk_tool_item_group_parent_class)->style_updated (widget);
 }
 
 static void
@@ -1572,7 +1581,7 @@ gtk_tool_item_group_class_init (GtkToolItemGroupClass *cls)
   wclass->size_allocate        = gtk_tool_item_group_size_allocate;
   wclass->realize              = gtk_tool_item_group_realize;
   wclass->unrealize            = gtk_tool_item_group_unrealize;
-  wclass->style_set            = gtk_tool_item_group_style_set;
+  wclass->style_updated        = gtk_tool_item_group_style_updated;
   wclass->screen_changed       = gtk_tool_item_group_screen_changed;
 
   cclass->add                = gtk_tool_item_group_add;
@@ -1751,7 +1760,7 @@ gtk_tool_item_group_set_label_widget (GtkToolItemGroup *group,
 
   if (priv->label_widget)
     {
-      gtk_widget_set_state (priv->label_widget, GTK_STATE_NORMAL);
+      gtk_widget_set_state_flags (priv->label_widget, 0, TRUE);
       gtk_container_remove (GTK_CONTAINER (alignment), priv->label_widget);
     }
 
@@ -1865,22 +1874,6 @@ gtk_tool_item_group_animation_cb (gpointer data)
   /* Enque this early to reduce number of expose events. */
   gtk_widget_queue_resize_no_redraw (GTK_WIDGET (group));
 
-  /* Figure out current style of the expander arrow. */
-  if (priv->collapsed)
-    {
-      if (priv->expander_style == GTK_EXPANDER_EXPANDED)
-        priv->expander_style = GTK_EXPANDER_SEMI_COLLAPSED;
-      else
-        priv->expander_style = GTK_EXPANDER_COLLAPSED;
-    }
-  else
-    {
-      if (priv->expander_style == GTK_EXPANDER_COLLAPSED)
-        priv->expander_style = GTK_EXPANDER_SEMI_EXPANDED;
-      else
-        priv->expander_style = GTK_EXPANDER_EXPANDED;
-    }
-
   gtk_tool_item_group_force_expose (group);
 
   /* Finish animation when done. */
@@ -1920,6 +1913,8 @@ gtk_tool_item_group_set_collapsed (GtkToolItemGroup *group,
                                            GTK_WIDGET (group));
   if (collapsed != priv->collapsed)
     {
+      GtkStyleContext *context;
+
       if (priv->animation)
         {
           if (priv->animation_timeout)
@@ -1931,14 +1926,23 @@ gtk_tool_item_group_set_collapsed (GtkToolItemGroup *group,
           g_source_set_callback (priv->animation_timeout,
                                  gtk_tool_item_group_animation_cb,
                                  group, NULL);
-
           g_source_attach (priv->animation_timeout, NULL);
+
+          context = gtk_widget_get_style_context (gtk_bin_get_child (GTK_BIN (priv->header)));
+
+          gtk_style_context_save (context);
+          gtk_style_context_add_class (context, GTK_STYLE_CLASS_EXPANDER);
+
+          gtk_style_context_notify_state_change (context,
+                                                 gtk_widget_get_window (priv->header),
+                                                 GUINT_TO_POINTER (1),
+                                                 GTK_STATE_FLAG_ACTIVE,
+                                                 !collapsed);
+
+          gtk_style_context_restore (context);
         }
-        else
-        {
-          priv->expander_style = GTK_EXPANDER_COLLAPSED;
-          gtk_tool_item_group_force_expose (group);
-        }
+      else
+        gtk_tool_item_group_force_expose (group);
 
       priv->collapsed = collapsed;
       g_object_notify (G_OBJECT (group), "collapsed");
@@ -2243,13 +2247,11 @@ gtk_tool_item_group_get_drop_item (GtkToolItemGroup *group,
                                    gint              y)
 {
   GtkAllocation allocation;
-  GtkOrientation orientation;
   GList *it;
 
   g_return_val_if_fail (GTK_IS_TOOL_ITEM_GROUP (group), NULL);
 
   gtk_widget_get_allocation (GTK_WIDGET (group), &allocation);
-  orientation = gtk_tool_shell_get_orientation (GTK_TOOL_SHELL (group));
 
   g_return_val_if_fail (x >= 0 && x < allocation.width, NULL);
   g_return_val_if_fail (y >= 0 && y < allocation.height, NULL);
@@ -2286,15 +2288,10 @@ _gtk_tool_item_group_item_size_request (GtkToolItemGroup *group,
   GList *it;
   gint rows = 0;
   gboolean new_row = TRUE;
-  GtkOrientation orientation;
-  GtkToolbarStyle style;
 
   g_return_if_fail (GTK_IS_TOOL_ITEM_GROUP (group));
   g_return_if_fail (NULL != item_size);
 
-  orientation = gtk_tool_shell_get_orientation (GTK_TOOL_SHELL (group));
-  style = gtk_tool_shell_get_style (GTK_TOOL_SHELL (group));
-
   item_size->width = item_size->height = 0;
 
   for (it = group->priv->children; it != NULL; it = it->next)
